@@ -6,8 +6,8 @@
 #
 # Parameters:
 # 1: The abbreviated name of sample input and output data files.
-#    E.g. 19 simultaneously means data/19.dot, data/19.lex and data/19.parse.
+#    E.g. 19 simultaneously means data/19.gv, data/19.lex and data/19.parse.
 # 2 & 3: Use to run the default renderer. E.g.: -o data/19.rend.
 #    Or, use for debugging. E.g.: -maxlevel debug.
 
-scripts/parse.sh data/$1.dot data/$1.lex data/$1.parse $2 $3
+scripts/parse.sh data/$1.gv data/$1.lex data/$1.parse $2 $3
